pub enum LogFormat {
Pretty,
Compact,
Json,
Full,
}Expand description
Log output format.
Variants
Pretty
Pretty format for human readability.
Compact
Compact format.
Json
JSON format for machine parsing.
Full
Full format with all details.
Implementations
Sourceimpl LogFormat
impl LogFormat
Sourcepub fn is_human_readable(&self) -> bool
pub fn is_human_readable(&self) -> bool
Check if this format is suitable for human reading.
Sourcepub fn is_machine_parseable(&self) -> bool
pub fn is_machine_parseable(&self) -> bool
Check if this format is suitable for machine parsing.