Scale configuration for simulations.
Defines how many devices, data points, and resources to simulate.
Structs
- Scale
Config - Scale configuration for simulations.
Enums
- Scale
Preset - Scale presets for common scenarios.
Scale configuration for simulations.
Defines how many devices, data points, and resources to simulate.