pub struct RequestTimer { /* private fields */ }Expand description
Request timer that automatically records duration to Prometheus when dropped.
This implements the RAII pattern for request timing. The duration is recorded when the timer goes out of scope.
Example
ⓘ
let _timer = metrics.time_request("modbus", "read");
// ... perform the operation ...
// duration is automatically recorded when _timer is droppedImplementations